/// Generators for some classic graphs.
pub mod classic;

/// Famous social networks.
pub mod social;

/// Random graphs
pub mod random;